@@ -131,32 +131,23 @@ current_clocksource'
         '''
         case_name:
             test_fips_selftest
-
         case_priority:
             2
-
         component:
             openssl
-
         bugzilla_id:
             1940085
-
         customer_case_id:
             02874840
-
         polarion_id:
             n/a
-
         maintainer:
             xiliang@redhat.com
-
         description:
             FIPS_selftest() pass
-
         key_steps:
             1. # gcc fipstest.c -o fipstest -lcrypto
             2. # # ./fipstest
-
         expected_result:
             No fips selftest failed.
         '''
@@ -173,16 +164,16 @@ current_clocksource'
 int fips_test(int fipsset){
     FIPS_mode_set(fipsset);
     if (FIPS_mode()){
-        printf("fips mode set.\\n");
+        fprintf(stderr, "fips mode set.\\n");
     }
     else{
-        printf("fips mode not set.\\n");
+        fprintf(stderr, "fips mode not set.\\n");
     }
     if (FIPS_selftest()){
-        printf("fips selftest pass.\\n");
+        fprintf(stderr, "fips selftest pass.\\n");
     }
     else{
-        printf("fips selftest failed.\\n");
+        fprintf(stderr, "fips selftest failed.\\n");
         ERR_print_errors_fp(stderr);
     }
 }
@@ -192,7 +183,11 @@ int main(int argc, char *argv[])
 	fips_test(1);
 }
         """
+        product_id = utils_lib.get_product_id(self)
+        if float(product_id) >= 9.0:
+            self.skipTest('openssl-3.0.0 does not provide FIPS_selftest() API bz:1969692')
         utils_lib.is_pkg_installed(self, pkg_name="openssl-devel")
+        utils_lib.is_pkg_installed(self, pkg_name="gcc")
         cmd = "echo '{}' > /tmp/fipstest.c".format(fipstest)
         utils_lib.run_cmd(self, cmd, expect_ret=0, msg='generate fipstest.c')
         cmd = "gcc /tmp/fipstest.c -o /tmp/fipstest -lcrypto"
@@ -270,16 +265,16 @@ int main(int argc, char *argv[])
         product_id = utils_lib.get_product_id(self)
         if float(product_id) < 8.4:
             self.skipTest('skip in earlier than el8.4')
-        self.log.info("Auto registeration only supports aws platform for now.")
+        self.log.info("Auto registeration only supports AWS and Azure platforms for now.")
 
+        cmd = "sudo subscription-manager config --rhsmcertd.auto_registration=1 --rhsm.manage_repos=0 --rhsmcertd.auto_registration_interval=1"
+        utils_lib.run_cmd(self, cmd, expect_ret=0, msg='try to enable auto_registration, disable managed_repos and change inverval from 60mins to 1min')
+        cmd = "sudo systemctl restart rhsmcertd"
+        utils_lib.run_cmd(self, cmd, expect_ret=0, msg='try to restart rhsmcertd service')
         cmd = "sudo subscription-manager config"
         utils_lib.run_cmd(self, cmd, expect_ret=0, expect_kw="auto_registration = 1,manage_repos = 0", msg='try to check subscription-manager config')
-        cmd = "sudo systemctl is-enabled rhsmcertd"
+        cmd = "sudo systemctl is-active rhsmcertd"
         utils_lib.run_cmd(self, cmd, expect_ret=0, msg='try to check rhsmcertd enabled')
-        cmd = "sudo subscription-manager config --rhsmcertd.auto_registration_interval=1"
-        utils_lib.run_cmd(self, cmd, expect_ret=0, msg='try to change rhsmcertd.auto_registration_interval from 60min to 1min')
-        cmd = "sudo systemctl restart rhsmcertd"
-        utils_lib.run_cmd(self, cmd, expect_ret=0, msg='restart rhsmcertd')
         start_time = time.time()
         timeout = 600
         interval = 60
@@ -373,32 +368,23 @@ RUN touch /tmp/test.txt
         '''
         case_name:
             test_podman_dev_null_permission
-
         case_priority:
             2
-
         component:
             podman
-
         bugzilla_id:
             1952698
-
         customer_case_id:
             02920986
-
         polarion_id:
             n/a
-
         maintainer:
             xiliang@redhat.com
-
         description:
             Make sure permission on /dev/null are not changing from 666 to 777 after running podman as root
-
         key_steps:
             1. # sudo podman run -d -p 80:80 httpd
             2. # ls -l /dev/null
-
         expected_result:
             /dev/null permission keeps 666
         '''
@@ -418,35 +404,27 @@ RUN touch /tmp/test.txt
         '''
         case_name:
             test_podman_leaks_exit
-
         case_priority:
             2
-
         component:
             podman
-
         bugzilla_id:
             1730281
-
         customer_case_id:
             02390622
-
         polarion_id:
             n/a
-
         maintainer:
             xiliang@redhat.com
-
         description:
             podman leaks kernel memory due to return code stored in tmpfs
-
         key_steps:
             1. $ podman run --name test -d ubi
             2. $ ls /run/libpod/exits/
-
         expected_result:
             Step2 return nothing.
         '''
+        utils_lib.is_cmd_exist(self, 'podman')
         self.log.info("Test podman can build an image using '--network container'")
         cmd = "podman ps -a"
         utils_lib.run_cmd(self, cmd, msg='try to list all containers before testing')
@@ -472,9 +450,9 @@ RUN touch /tmp/test.txt
         cmd = "podman rm -a -f"
         utils_lib.run_cmd(self, cmd, msg='try to clean all containers before testing')
         cmd = "podman run --name myctr1 -td quay.io/libpod/alpine"
-        utils_lib.run_cmd(self, cmd, expect_ret=0, msg='run myctr1')
+        utils_lib.run_cmd(self, cmd, expect_ret=0, msg='run myctr1', timeout=180)
         cmd = "podman run --name myctr2 -td quay.io/libpod/alpine"
-        utils_lib.run_cmd(self, cmd, expect_ret=0, msg='run myctr2')
+        utils_lib.run_cmd(self, cmd, expect_ret=0, msg='run myctr2', timeout=180)
         cmd = "timeout 5 podman exec myctr1 sleep 10"
         utils_lib.run_cmd(self, cmd)
         cmd = "podman kill myctr1"
@@ -499,37 +477,28 @@ RUN touch /tmp/test.txt
         '''
         case_name:
             test_virsh_pci_reattach
-
         case_priority:
             1
-
         component:
             kernel
-
         bugzilla_id:
             1700254
-
         polarion_id:
             n/a
-
         maintainer:
             xiliang@redhat.com
-
         description:
             Test no exception when system does pci detach and attach operation in virsh.
             virsh can detach host pci device and attach it to guest.
-
         key_steps:
             1. #virsh  nodedev-detach $pci
             2. #virsh  nodedev-reattach $pci
-
         expected_result:
             No panic/crash happen.
             eg. # virsh nodedev-detach pci_0000_2b_00_0
                 Device pci_0000_2b_00_0 detached
                 # virsh nodedev-reattach pci_0000_2b_00_0
                 Device pci_0000_2b_00_0 re-attached
-
         '''
         utils_lib.is_metal(self, action="cancel")
         cmd = "sudo yum install -y libvirt"
