@@ -1,6 +1,8 @@
 import unittest
 from os_tests.libs import utils_lib
+import os_tests
 import time
+import os
 
 class TestLTP(unittest.TestCase):
 
@@ -29,43 +31,36 @@ class TestLTP(unittest.TestCase):
 
     def setUp(self):
         utils_lib.init_case(self)
+        utils_dir = os.path.realpath(os_tests.__file__)
+        utils_dir = os.path.dirname(utils_dir) + '/utils'
         if utils_lib.is_arch(self, arch='aarch64'):
-            ltp_url = self.params.get('ltp_url_aarch64')
+            ltp_rpm = utils_dir + '/ltp-master.aarch64.rpm'
         else:
-            ltp_url = self.params.get('ltp_url_x86_64')
-        utils_lib.pkg_install(self, pkg_name='ltp', pkg_url=ltp_url)
+            ltp_rpm = utils_dir + '/ltp-master.x86_64.rpm'
+        utils_lib.pkg_install(self, pkg_name='ltp', pkg_url=ltp_rpm)
         self.cursor = utils_lib.get_cmd_cursor(self, cmd='journalctl --since today', rmt_redirect_stdout=True)
 
     def test_ltp_add_key02(self):
         '''
         case_name:
             test_ltp_add_key02
-
         case_priority:
             1
-
         component:
             kernel
-
         bugzilla_id:
             1464851
-
         polarion_id:
             RHEL7-98753
-
         maintainer:
             xiliang@redhat.com
-
         description:
             Ran ltp syscalls add_key02.
-
         key_steps:
             1. Install ltp pkg
             2. # /opt/ltp/runltp -f syscalls -s add_key02
-
         expected_result:
             No panic or hang happen.
-
         '''
         self._ltp_run(case_name="add_key02")
 
@@ -118,29 +113,21 @@ at least which ltp not handle')
         '''
         case_name:
             test_ltp_quickhit
-
         case_priority:
             1
-
         component:
             kernel
-
         bugzilla_id:
             n/a
-
         polarion_id:
             n/a
-
         maintainer:
             xiliang@redhat.com
-
         description:
             Ran ltp quickhit senario to test kernel quickly.
-
         key_steps:
             1. Install ltp pkg
             2. # /opt/ltp/runltp -f quickhit
-
         expected_result:
             No panic or hang or other exception happen.
         '''
